open_connection

Function open_connection 

pub async fn open_connection(
    config: &LibSqlConfig,
) -> Result<OpenedConnection, StoreError>
Open the configured libSQL database and return its handle and connection.

Operator-provided journal and synchronous settings are applied only when present on the configuration. This crate intentionally does not choose durability defaults for omitted tunables.

Errors

Returns StoreError::Backend when libSQL cannot build/connect the database or when applying an explicitly configured PRAGMA fails.